#
# spec file for package lastpass-cli
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lastpass-cli
Version:        1.3.4
Release:        1.6
Summary:        LastPass command line interface tool
License:        GPL-2.0-only
Group:          Productivity/Security
URL:            https://github.com/LastPass/lastpass-cli
Source:         https://github.com/lastpass/lastpass-cli/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM 0001-Mark-global-variable-as-extern.patch gh#lastpass/lastpass-cli#532
Patch0:         0001-Mark-global-variable-as-extern.patch
BuildRequires:  asciidoc
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libxslt-tools
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(openssl)
Recommends:     bash-completion
Recommends:     pinentry
Recommends:     xclip

%description
LastPass is a freemium password management service which stores encrypted
passwords in the cloud. This package provided it's command line interface
tool.

%prep
%autosetup -p 1

%build
%cmake \
  -DTEST_BUILD=ON
%make_jobs all doc-man

%install
%cmake_install install-doc
install -Dpm  0644 contrib/lpass_bash_completion \
  %{buildroot}%{_datadir}/bash-completion/completions/lpass
install -Dpm 0644 contrib/lpass_zsh_completion \
  %{buildroot}%{_datadir}/zsh/site-functions/_lpass
install -Dpm 0644 contrib/completions-lpass.fish \
  %{buildroot}%{_datadir}/fish/completions/completions-lpass.fish

%check
%make_build test

%files
%license COPYING
%doc CHANGELOG.md README.md
%{_bindir}/lpass
%{_mandir}/man1/lpass.1%{?ext_man}
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/lpass
%dir %{_datadir}/fish
%dir %{_datadir}/fish/completions
%{_datadir}/fish/completions/completions-lpass.fish
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_lpass

%changelog
* Fri Jan 20 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.4:
  * Updating post parameter
* Sat Jun  6 2020 Matthias Eliasson <elimat@opensuse.org>
- Add patch 0001-Mark-global-variable-as-extern.patch to fix builds with gcc10
* Wed May 29 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.3.3:
  * Decrease the time for the cli app to do things (Wesley Schwengle)
  * 'blob_load' refactor (Wesley Schwengle)
  * Fixed bug where logout requires login (Wesley Schwengle)
  * Fix non-default PKG_CONFIG_PATH on macOS (Alyssa Ross)
- Changes for version 1.3.2:
  * Don't require using make (Eli Schwartz)
  * Disable IPv6 support (Wesley Schwengle)
  * Link against Brew Curl on MacOS (Tom Sullivan)
  * Autogenerate versions from git (Wesley Schwengle/Eli Schwartz)
  * Remove memory leak in config_path_for_type (Tom Sullivan)
  * Install bash-completions in PREFIX dir (Wesley Schwengle)
  * Include libgen.h for BSD builds (Tom Sullivan)
  * Create subdirectories when determining config path (Tom Sullivan)
  * Only show basename in usage (William Casarin)
  * Fix segmentation fault on BSD while running make test (Björn Ketelaars)
  * README.md updates:
    + Brew formula installation (Thomas Haggett)
    + Ubuntu Xenial dependencies (Nick Timkovich)
    + Debian stable/testing and Ubuntu dependencies (Wesley Schwengle)
* Tue Jun 12 2018 ggkioulis@suse.com
- Update to version 1.3.1:
  * Revert "pins: remove GlobalSign R1/R3 pins" from Robert Copeland
  * Readme update from Wesley Schwengle
  * Add Dockerfile to create a clean build environment from Wesley Schwengle
  * Missing dependencies in readme
  * Added CLion project files to ignore list
* Fri Apr  6 2018 mpluskal@suse.com
- Update to version 1.3.0:
  * lpass show now supports --json format
  * lpass show now supports --quiet flag to suppress prompts
  * lpass import has --keep-dupes flag which will preserve
    duplicate accounts on import
  * LPASS_PINENTRY environment variable may now be used to set
    custom path to pinentry
  * Build fix for aarch64 and others
  * New fish completions
  * Zsh completions
  * bugfix: site notes now show up in notes textarea instead of
    fields
  * spelling fixes
- Modernise spec file
- Install autocompletions
* Thu Oct 26 2017 mpluskal@suse.com
- Update to version 1.2.2:
  * lpass ls --format now supports "%%al" to show URL
  * $VISUAL can be used in preference to $EDITOR
  * lpass edit can now directly edit multiline ssh keys
  * fields are now preserved when edited with lpass edit
  * Bugfix: use-after-free in http.c fixed
  * Bugfix: command-line completion now works for names with spaces
  * Bugfix: loading attachments from shared folders now works
  * Documentation updates
* Tue Jul 11 2017 mpluskal@suse.com
- Update to version 1.2.1:
  * fix regression with lpass show not displaying all fields for
    secure notes
* Thu Jun  8 2017 mpluskal@suse.com
- Update to version 1.2.0:
  * lpass show now supports new-style multiline ssh keys
  * lpass export now supports --fields=FIELDLIST argument to
  * control output, with patches from Kyle Burton
  * lpass ls now always shows empty shared folders
  * lpass edit can now set the 'master password reprompt' field in
    sites
  * lpass share create now shows the created share name
  * Bugfix: crash in lpass show fixed by Kyle Burton
  * build fixes for termux and documentation updates, from
    Christian Rondeau
  * documentation updates for Ubuntu from Craig Menning and Glenn
    Oppegard
  * Test suite now included covering basic operations
- Enable tests
* Fri Feb 17 2017 mpluskal@suse.com
- Update to version 1.1.2:
  * Bugfix: crash with lpass logout --color=never fixed
  * Bugfix: lpass add with secure notes works again
  * Bugfix: sort order in lpass ls is now consistent whether or not
    colors are used
  * Documentation has been enhanced to describe aliases and more
    options, with patches by Eric B. Hymowitz.
- Changes for version 1.1.1:
  * Bugfix: fix crash in lpass show for secure notes without
    attachments
  * Build: fix build on OpenBSD, from Björn Ketelaars
  * Build: fix build when using LibreSSL, from Björn Ketelaars
- Changes for version 1.1.0:
  * New command lpass import can import an existing csv file (or
    output from lpass export) into the vault lpass show and lpass
    ls learned a --format argument to enable user-specified
    printf-style formats
  * Bash completions will now complete field names if --field is
    specified after the account name
  * Build: cmake now used for building, by Filippo Cucchetto and
    with fixes by Eli Schwartz
  * Build: lpass has been updated to work with OpenSSL 1.1
  * Bugfix: crash in lpass ls -l with no last_modified_gmt fixed
  * Bugfix: secure notes editing with "Name" fields now works
    properly
  * Bugfix: editing secure note names now works (github #106)
  * Bugfix: lpass-created server secure notes are now compatible
    with the plugin
  * Bugfix: generate now uses all defined characters, by Ignat
    Korchagin
  * Bugfix: lpass show for ssh-key secure notes no longer corrupts
  * password-protected ssh keys (github #232)
* Sun Jul 31 2016 mpluskal@suse.com
- Update to version 1.0.0:
  * New command lpass status shows whether or not the user is
    logged in with agent, from Nick Knudson
  * lpass add can now be passed --note-type=X in order to add a
    secure note using a template. Specifying an unknown note
    template will list the available templates.
  * lpass ls now shows username with --long, from Alli Witheford
  * Bash completions are now installed with make install, from
    Eli Schwartz
  * Fish shell completions supplied by Joar Wanboarg
  * Initial support for adding (lpass add --app) and editing
    applications
  * Updates to manpage for ls, passwd, add, and basic usage
    examples
  * lpass now follows XDG base directory specifications for its
    files on platforms that use it. Set LP_HOME to ~/.lpass to
    keep the previous location
  * Bugfix: resolved syncing problems on some platforms
    (notably RHEL/CentOS) related to improper multiprocess usage
    of libcurl (github #166)
  * Bugfix: lpass show no longer crashes when a searched-for field
    is not found (github #167)
  * Bugfix: lpass no longer exits with an error if the blob is
    empty but otherwise without parsing errors. This fixes the case
    where a new user could not use the application without first
    adding a site elsewhere.
  * LPASS_LOG_LEVEL learned level=8 with which lpass will also dump
    libcurl verbose logs showing all traffic for debugging (not
    recommended for general use due to potentially sensitive
    headers being logged).
* Sat Apr 16 2016 mpluskal@suse.com
- Initial package for version 0.9.0
